@@ -6,8 +6,8 @@ from conf.config import LOG_LEVEL
 
 logger = logging.getLogger("dingding_notify")
 
-# formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
-formatter = logging.Formatter('[%(asctime)s] %(name)s %(levelname)s %(pathname)s %(lineno)d %(message)s')
+formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
+# formatter = logging.Formatter('[%(asctime)s] %(name)s %(levelname)s %(pathname)s %(lineno)d %(message)s')
 
 stream_handler = logging.StreamHandler(sys.stderr)
 stream_handler.setFormatter(formatter)
